"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
var __importStar = (this && this.__importStar) || function (mod) {
    if (mod && mod.__esModule) return mod;
    var result = {};
    if (mod != null) for (var k in mod) if (Object.hasOwnProperty.call(mod, k)) result[k] = mod[k];
    result["default"] = mod;
    return result;
};
Object.defineProperty(exports, "__esModule", { value: true });
const clone_1 = __importDefault(require("clone"));
const Server_1 = require("../Server");
const ModuleManager_1 = require("../ModuleManager");
const Config_1 = require("../Config");
const ServiceManager_1 = require("../ServiceManager");
const EventManager_1 = require("../EventManager");
const ApplicationEvents_1 = require("./ApplicationEvents");
const debug_1 = require("../../debug");
const defaultConfig = __importStar(require("../../config"));
const Cli_1 = require("../Cli");
const ApplicationModes_1 = require("./ApplicationModes");
const debug = debug_1.createDebugLogger('application');
class Application {
    constructor(...appConfigs) {
        this.environment = process.env.NODE_ENV || 'development';
        this.applicationConfigs = appConfigs;
        this.config = new Config_1.Config(defaultConfig, ...clone_1.default(this.applicationConfigs));
        this.serviceManager = new ServiceManager_1.ServiceManager({
            aliases: { config: Config_1.Config, sharedEventManager: EventManager_1.SharedEventManager },
            invokables: new Map([
                [EventManager_1.SharedEventManager, EventManager_1.SharedEventManager],
            ]),
            factories: new Map([
                [ModuleManager_1.ModuleManager, ModuleManager_1.ModuleManagerFactory],
                [EventManager_1.EventManager, EventManager_1.EventManagerFactory],
            ]),
            services: new Map([
                [Config_1.Config, this.config],
                [Application, this],
            ]),
            shared: new Map([
                [EventManager_1.EventManager, false],
            ]),
        });
    }
    getMode() {
        return this.mode;
    }
    getServiceManager() {
        return this.serviceManager;
    }
    async bootstrap(mode, loadOnly = false) {
        const config = this.config;
        // Make the module manager. Only one level is allowed to specify module configs..
        this.moduleManager = this.serviceManager.get(ModuleManager_1.ModuleManager);
        // Initialize module manager. Only calls getConfig()
        await this.moduleManager.loadModules(config.of('modules'));
        // Now let's patch on the user config once more, to ensure dominance.
        this.config.merge(...this.applicationConfigs);
        // Now that we have all the configs, register the services.
        this.serviceManager.configure(config.of('services'));
        // go forth and create all core services.
        this.sharedEventManager = this.serviceManager.get(EventManager_1.SharedEventManager);
        if (mode === ApplicationModes_1.ApplicationModes.Cli) {
            await this.bootstrapCli();
        }
        else {
            this.bootstrapServer();
        }
        // Don't start the application. We're probably in CLI mode.
        if (loadOnly) {
            return this;
        }
        return await this.start();
    }
    async start() {
        // Cool cool. Bootstrap the modules, because they can now get all the things.
        await this.moduleManager.bootstrap();
        // Allow listeners to do some work before starting the server.
        await this.sharedEventManager.trigger(ApplicationEvents_1.ApplicationEvents.Ready, this);
        return this;
    }
    async bootstrapCli() {
        const cliService = await this.serviceManager.get(Cli_1.CliService);
        this.sharedEventManager.attachOnce(ApplicationEvents_1.ApplicationEvents.Ready, () => {
            cliService.execute(process.argv.slice(2));
        });
    }
    bootstrapServer() {
        const serverService = this.serviceManager.get(Server_1.ServerService);
        this.sharedEventManager.attachOnce(ApplicationEvents_1.ApplicationEvents.Ready, () => {
            serverService.start();
        });
    }
    getEnvironment() {
        return this.environment;
    }
    isProduction() {
        return this.getEnvironment() === 'production';
    }
    async launch(mode = ApplicationModes_1.ApplicationModes.Server, loadOnly = false) {
        this.config.merge({ application: { mode } });
        this.mode = mode;
        debug(`Launching in ${mode} mode`);
        await this.bootstrap(mode, loadOnly);
        debug('Application ready.');
        return this;
    }
}
exports.Application = Application;
//# sourceMappingURL=Application.js.map