"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
const cli_table_1 = __importDefault(require("cli-table"));
const prettyjson_1 = __importDefault(require("prettyjson"));
const pretty_error_1 = __importDefault(require("pretty-error"));
const chalk_1 = __importDefault(require("chalk"));
class Output {
    constructor() {
        this.exitCode = 0;
        this.data = [];
        this.prettyError = new pretty_error_1.default();
    }
    static create() {
        return new this();
    }
    static errorOutput(error, exitCode) {
        const output = new this();
        output.error(error, exitCode);
        return output;
    }
    /**
     * Exit code to use upon send.
     *
     *  NOTE: Exit codes 1 - 2, 126 - 165, and 255 have special meanings
     *        and should therefore be avoided for user-specified exit parameters.
     *        Try restricting user-defined exit codes to the range 64 - 113 (in addition to 0, for success).
     *
     * 1 - Catchall for general errors
     * 2 - Misuse of shell builtins (according to Bash documentation)
     * 126 - Command invoked cannot execute
     * 127 - “command not found”
     * 128 - Invalid argument to exit
     * 128+n - Fatal error signal “n”
     * 130 - Script terminated by Control-C
     * 255\* - Exit status out of range
     *
     * @see http://tldp.org/LDP/abs/html/exitcodes.html
     *
     * @param {Number} exitCode
     *
     * @return {this}
     */
    setExitCode(exitCode) {
        this.exitCode = exitCode;
        return this;
    }
    addData(...data) {
        data.forEach(item => {
            if (item === undefined) {
                return;
            }
            if (item.constructor === Object) {
                return this.addData(prettyjson_1.default.render(item));
            }
            this.data.push(item);
        });
        return this;
    }
    success(message, data) {
        this.addData(chalk_1.default `\n  {green {bold Success!}} ${message}\n`, data);
    }
    resetData() {
        this.data = [];
        return this;
    }
    addHorizontalTable(head, data, options = {}) {
        const table = new cli_table_1.default(Object.assign({ head }, options));
        table.push(...data);
        this.addData(table.toString());
        return this;
    }
    addVerticalTable(data, options) {
        const table = new cli_table_1.default(options);
        table.push(...data);
        this.addData(table.toString());
        return this;
    }
    addCrossTable(head, data, options = {}) {
        const table = new cli_table_1.default(options);
        table.push(...data);
        this.addData(table.toString());
        return this;
    }
    /**
     * Add/set an error to output.
     *
     * @param {Error|string}  [error]     The error to write.         Default to "Unknown error".
     * @param {Number|null}   [exitCode]  The code to exit with.      Default to 1. Use null to not change the exitCode.
     * @param {boolean}       [clear]     Clear previously set data.  Default to false.
     *
     * @return {this}
     */
    error(error = 'Unknown error', exitCode = 1, clear = false) {
        if (!this.prettyError) {
            this.prettyError = new pretty_error_1.default();
        }
        if (exitCode) {
            this.setExitCode(exitCode);
        }
        if (clear) {
            this.resetData();
        }
        this.addData(this.prettyError.render(error));
        return this;
    }
    /**
     * Write the output to the console.
     */
    flush() {
        this.data.forEach((piece) => console.log(piece));
    }
    send() {
        this.flush();
        process.exit(this.exitCode);
    }
}
exports.Output = Output;
//# sourceMappingURL=Output.js.map